import { Dayjs } from 'dayjs';
import { NotificationType, TaskStatus, TaskType } from './API.helper';

declare namespace API {
  export interface ResponseData<T> {
    code: number | string;
    data: T;
    message?: string;
    /**
     * 用于表明http请求是否成功
     */
    success: boolean;
    /**
     * 用于标明业务请求内容是否成功,
     * 等价于code === 0
     */
    requestIsSuccess: boolean;
  }
}

declare namespace DATA {
  export interface User {
    id: string;
    backgroundPermission: number;
    /**
     * 姓名
     */
    cnName: string;
    companyId: string;
    deptId: string;
    /**
     * 部分名称
     */
    deptName: string;
    email: string;
    /**
     * 头像
     */
    headImgUrl: string;
    /**
     * 手机号
     */
    phone: string;
  }

  export interface SocketFileMsg {
    archName: string;
    commonStatus: number; // 1,
    createTime: string; // "2021-04-16T19:33:36+08:00",
    createUserId: string; // "367294106252087297",
    createUserName: string; // "",
    deleted: number; // 0,
    extension: string; // "pdf",
    fileSize: number; // 9385910,
    folderId: string; // "389513225458573314",
    folderLevelId: string; // "389513225454379009_342050628186824706",
    id: string; //  "389513618179645440",
    ipfsCid: string; // "QmPYXHLuXoTF7A1BxsgTRVByojMXyWjjrrZS5MQeTX1mNq",
    isShowRecycle: number; // 0,
    milestone: number; // 1,
    modifyName: string; // "",
    modifyTime: string; // "2021-04-16T19:36:28+08:00",
    modifyUserId: string; // "0",
    nodeName: string; // "产品分析",
    projId: string; // "389513225454379008",
    projName: string; // "2021416-1",
    relativePath: string; // "",
    showUrl: string; // "",
    status: number; // 2,
    syncFileSize: number; // 9385910,
    syncIpfsCid: string; // "QmPYXHLuXoTF7A1BxsgTRVByojMXyWjjrrZS5MQeTX1mNq",
    syncVersion: number; // 1,
    taskId: string; // 420964845295652864,
    taskIsModify: boolean; // false,
    taskSyncProgress: 100;
    taskSyncStatus: TaskStatus; // "TASK_SYNC_STATUS_FINISH",
    taskType: TaskType; // "DOWNLOAD",
    taskCreateUnixTime: number; // 秒级时间
    taskCreateDate: Dayjs; // 前端根据taskCreateUnixTime生成的时间对象
    taskCreateDateStr: string; //  前端根据taskCreateUnixTime生成的时间字符串 供给消息窗口使用, 格式: YY/MM/DD HH:mm:ss
    absolutePath: string; // 绝对路径
    version: number; // 1,
    workStatus: number; // 1
    /* 消息通知型数据补完 */
    originData: any; // 用于消息通知
    /**
     * 通知类型
     */
    notifyType: NotificationType;
    /**
     * 通知消息内容
     */
    notifyMessage: string;
  }
}
